==> moodle-1.6.3p0.tgz: moodle/lang/en_utf8/assignment.php <==
<?php // $Id: assignment.php,v 1.2.2.1 2006/07/13 07:42:13 moodler Exp $
      // assignment.php - created with Moodle 1.2 + (2004032100)


$string['allowresubmit'] = 'Allow resubmitting';
$string['assignmentdetails'] = 'Assignment details';
$string['assignmentmail'] = '$a->teacher has posted some feedback on your
assignment submission for \'$a->assignment\'

You can see it appended to your assignment submission:

    $a->url';
$string['assignmentmailhtml'] = '$a->teacher has posted some feedback on your
assignment submission for \'<i>$a->assignment</i>\'<br /><br />
You can see it appended to your <a href=\"$a->url\">assignment submission</a>.';
$string['assignmentname'] = 'Assignment name';
$string['assignmenttype'] = 'Assignment type';
$string['availabledate'] = 'Available from';
$string['allowmultiple'] = 'Allow multiple files';
$string['attachfile'] = 'Attach file';
$string['attachfiletoassignment'] = 'Attach file(s) to assignment';
$string['backtoassignment'] = 'Back to Assignment';
$string['backtofeedback'] = 'Back to Feedback';
$string['choosereviewfile'] = 'Choose a file to upload as an assignment review:';
$string['comment'] = 'Comment';
$string['commentinline'] = 'Comment inline';
$string['configitemstocount'] = 'Nature of items to be counted for student submissions in online assignments.';
$string['configmaxbytes'] = 'Default maximum assignment size for all assignments on the site (subject to course limits and other local settings)';
$string['deletecheckfile'] = 'Are you absolutely sure you want to delete this file?';
$string['deleteednotification'] = 'File has been deleted.';
$string['deletefail'] = 'The following file has not been deleted:';
$string['description'] = 'Description';
$string['duedate'] = 'Due date';
$string['duedateno'] = 'No due date';
$string['early'] = '$a early';
$string['editmysubmission'] = 'Edit my submission';
$string['emailstudents'] = 'Email alerts to students';
$string['emailteachers'] = 'Email alerts to teachers';
$string['emailteachermail'] = '
$a->username has updated their assignment submission
for \'$a->assignment\'

It is available here:

    $a->url';
$string['emailteachermailhtml'] = '$a->username has updated their assignment submission
for <i>\'$a->assignment\'</i><br /><br />
It is <a href=\"$a->url\">available on the web site</a>.';
$string['emptysubmission'] = 'You have not submitted anything yet';
$string['existingfiledeleted'] = 'Existing file has been deleted: $a';
$string['failedupdatefeedback'] = 'Failed to update submission feedback for user $a';
$string['feedback'] = 'Feedback';
$string['feedbackfromteacher'] = 'Feedback from the $a';
$string['feedbackupdated'] = 'Submissions feedback updated for $a people';
$string['graded'] = 'Graded';
$string['guestnoupload'] = 'Sorry, guests are not allowed to upload';
$string['guestnosubmit'] = 'Sorry, guests are not allowed to submit an assignment. You have to log in/ register before you can submit your answer';
$string['helpoffline'] = '<p>This is useful when the assignment is performed outside of Moodle.  It could be
   something elsewhere on the web or face-to-face.</p><p>Students can see a description of the assignment, 
   but can\'t upload files or anything.  Grading works normally, and students will get notifications of 
   their grades.</p>';
$string['helponline'] = '<p>This assignment type asks users to edit a text, using the normal
   editing tools.  Teachers can grade them online, and even add inline comments or changes.</p>
   <p>(If you are familiar with older versions of Moodle, this Assignment
   type does the same thing as the old Journal module used to do.)</p>';
$string['helpupload'] = '<p>This type of assignment allows each participant to upload one or several files, of any type.</p> 
   <p>These might be a Word processor documents, images, a zipped web site, or anything you ask them to submit.</p>
   <p>This type also allows you to upload multiple response files of any type.</p>'; 
$string['helpuploadsingle'] = '<p>This type of assignment allows each participant to upload a 
   single file, of any type.</p> <p>This might be a Word processor document, an image, 
   a zipped web site, or anything you ask them to submit.</p>';
$string['late'] = '$a late';
$string['markingsubmitnotification'] = 'File has been submitted for marking successfully.';
$string['maximumgrade'] = 'Maximum grade';
$string['maximumsize'] = 'Maximum size';
$string['modulename'] = 'Assignment';
$string['modulenameplural'] = 'Assignments';
$string['namedeletefile'] = 'You about to delete this file:';
$string['newsubmissions'] = 'Assignments submitted';
$string['noassignments'] = 'There are no assignments yet';
$string['noattempts'] = 'No attempts have been made on this assignment';
$string['nofilesforsubmit'] = 'No file was found for submitting - are you sure you uploaded any?';
$string['notgradedyet'] = 'Not graded yet';
$string['notsubmittedyet'] = 'Not submitted yet';
$string['onceassignmentsent'] = 'Once the assignment is sent for marking, you will no longer be able to delete or attach file(s).';
$string['overwritewarning'] = 'Warning: uploading again will REPLACE your current submission';
$string['pagesize'] = 'Submissions shown per page';
$string['preventlate'] = 'Prevent late submissions';
$string['quickgrade'] = 'Allow quick grading';
$string['removelink'] = 'Remove';
$string['responsefile'] = 'Response File:';
$string['responsesfromteacher'] = 'Responses Uploaded by the Teacher';
$string['saveallfeedback'] = 'Save all my feedback';
$string['sendformarking'] = 'Send for marking';
$string['step1'] = 'Step 1: ';
$string['step2'] = 'Step 2: ';
$string['submissionstatusblank'] = 'Blank';
$string['submissionstatusdraft'] = 'Draft';
$string['submissionstatusmarked'] = 'Marked';
$string['submissionstatusreturned'] = 'Returned';
$string['submissionstatus'] = 'Submission status:';
$string['submissionstatussubmitted'] = 'Submitted';
$string['submission'] = 'Submission';
$string['submissionfeedback'] = 'Submission feedback';
$string['submissions'] = 'Submissions';
$string['submissionsaved'] = 'Your changes have been saved';
$string['submissionsnotgraded'] = '$a submissions not graded';
$string['submitassignment'] = 'Submit your assignment using this form';
$string['submitformarking'] = 'Submit assignment for marking';
$string['submitted'] = 'Submitted';
$string['typeoffline'] = 'Offline activity';
$string['typeonline'] = 'Online text';
$string['typeupload'] = 'Advanced uploading of files';
$string['typeuploadsingle'] = 'Upload a single file';
$string['uploadbadname'] = 'This filename contained strange characters and couldn\'t be uploaded';
$string['uploadedfiles'] = 'uploaded files';
$string['uploaderror'] = 'An error happened while saving the file on the server';
$string['uploadfailnoupdate'] = 'File was uploaded OK but could not update your submission!';
$string['uploadfiletoobig'] = 'Sorry, but that file is too big (limit is $a bytes)';
$string['uploadnofilefound'] = 'No file was found - are you sure you selected one to upload?';
$string['uploadnotregistered'] = '\'$a\' was uploaded OK but submission did not register!';
$string['uploadsuccess'] = 'Uploaded \'$a\' successfully';
$string['uploadsuccessresponse'] = 'Response file uploaded successfully.';
$string['viewfeedback'] = 'View assignment grades and feedback';
$string['viewsubmissions'] = 'View $a submitted assignments';
$string['yoursubmission'] = 'Your submission';

?>

==> moodle-1.7.tgz: moodle/lang/en_utf8/assignment.php <==
<?PHP // $Id: assignment.php,v 1.9.2.2 2006/11/01 09:37:06 moodler Exp $ 
      // assignment.php - created with Moodle 1.7 beta + (2006101003)


$string['allowdeleting'] = 'Allow deleting';
$string['allowmaxfiles'] = 'Maximum number of uploaded files';
$string['allownotes'] = 'Allow notes';
$string['allowresubmit'] = 'Allow resubmitting';
$string['assignment:grade'] = 'Grade assignment';
$string['assignment:submit'] = 'Submit assignment';
$string['assignment:view'] = 'View assignment';
$string['assignmentdetails'] = 'Assignment details';
$string['assignmentmail'] = '$a->teacher has posted some feedback on your
assignment submission for \'$a->assignment\'

You can see it appended to your assignment submission:

    $a->url';
$string['assignmentmailhtml'] = '$a->teacher has posted some feedback on your
assignment submission for \'<i>$a->assignment</i>\'<br /><br />
You can see it appended to your <a href=\"$a->url\">assignment submission</a>.';
$string['assignmentname'] = 'Assignment name';
$string['assignmenttype'] = 'Assignment type';
$string['availabledate'] = 'Available from';
$string['comment'] = 'Comment';
$string['commentinline'] = 'Comment inline';
$string['configitemstocount'] = 'Nature of items to be counted for student submissions in online assignments.';
$string['configmaxbytes'] = 'Default maximum assignment size for all assignments on the site (subject to course limits and other local settings)';
$string['confirmdeletefile'] = 'Are you absolutely sure you want to delete this file?<br /><strong>$a</strong>';
$string['deletefilefailed'] = 'Deleting of file failed.';
$string['description'] = 'Description';
$string['draft'] = 'Draft';
$string['duedate'] = 'Due date';
$string['duedateno'] = 'No due date';
$string['early'] = '$a early';
$string['editmysubmission'] = 'Edit my submission';
$string['emailstudents'] = 'Email alerts to students';
$string['emailteachermail'] = '$a->username has updated their assignment submission
for \'$a->assignment\'

It is available here:

    $a->url';
$string['emailteachermailhtml'] = '$a->username has updated their assignment submission
for <i>\'$a->assignment\'</i><br /><br />
It is <a href=\"$a->url\">available on the web site</a>.';
$string['emailteachers'] = 'Email alerts to teachers';
$string['emptysubmission'] = 'You have not submitted anything yet';
$string['existingfiledeleted'] = 'Existing file has been deleted: $a';
$string['failedupdatefeedback'] = 'Failed to update submission feedback for user $a';
$string['feedback'] = 'Feedback';
$string['feedbackfromteacher'] = 'Feedback from the $a';
$string['feedbackupdated'] = 'Submissions feedback updated for $a people';
$string['graded'] = 'Graded';
$string['guestnosubmit'] = 'Sorry, guests are not allowed to submit an assignment. You have to log in/ register before you can submit your answer';
$string['guestnoupload'] = 'Sorry, guests are not allowed to upload';
$string['helpoffline'] = '<p>This is useful when the assignment is performed outside of Moodle.  It could be
   something elsewhere on the web or face-to-face.</p><p>Students can see a description of the assignment, 
   but can\'t upload files or anything.  Grading works normally, and students will get notifications of 
   their grades.</p>';
$string['helponline'] = '<p>This assignment type asks users to edit a text, using the normal
   editing tools.  Teachers can grade them online, and even add inline comments or changes.</p>
   <p>(If you are familiar with older versions of Moodle, this Assignment
   type does the same thing as the old Journal module used to do.)</p>';
$string['helpupload'] = '<p>This type of assignment allows each participant to upload one or more files in any format. 
   These might be a Word processor documents, images, a zipped web site, or anything you ask them to submit.</p>
   <p>This type also allows you to upload multiple response files. Response files can be also uploaded before submission which
   can be used to give each participant different file to work with.</p>
   <p>Participants may also enter notes describing the submitted files, progress status or any other text information.</p>
   <p>Submission of this type of assignment must be manually finalized by the participant. You can review the current status
   at any time, unfinished assignments are marked as Draft. You can revert any ungraded assignment back to draft status.</p>';
$string['helpuploadsingle'] = '<p>This type of assignment allows each participant to upload a 
   single file, of any type.</p> <p>This might be a Word processor document, an image, 
   a zipped web site, or anything you ask them to submit.</p>';
$string['hideintro'] = 'Hide description before available date';
$string['late'] = '$a late';
$string['maximumgrade'] = 'Maximum grade';
$string['maximumsize'] = 'Maximum size';
$string['modulename'] = 'Assignment';
$string['modulenameplural'] = 'Assignments';
$string['newsubmissions'] = 'Assignments submitted';
$string['noassignments'] = 'There are no assignments yet';
$string['noattempts'] = 'No attempts have been made on this assignment';
$string['nofiles'] = 'No files were submitted';
$string['nofilesyet'] = 'No files submitted yet';
$string['notavailableyet'] = 'Sorry, this assignment is not yet available.<br />Assignment instructions will be displayed here on the date given bellow.';
$string['notes'] = 'Notes';
$string['notesempty'] = 'No entry';
$string['notesupdateerror'] = 'Error when updating notes';
$string['notgradedyet'] = 'Not graded yet';
$string['notsubmittedyet'] = 'Not submitted yet';
$string['onceassignmentsent'] = 'Once the assignment is sent for marking, you will no longer be able to delete or attach file(s). Do you want to continue?';
$string['overwritewarning'] = 'Warning: uploading again will REPLACE your current submission';
$string['pagesize'] = 'Submissions shown per page';
$string['preventlate'] = 'Prevent late submissions';
$string['quickgrade'] = 'Allow quick grading';
$string['responsefiles'] = 'Response files';
$string['reviewed'] = 'Reviewed';
$string['saveallfeedback'] = 'Save all my feedback';
$string['sendformarking'] = 'Send for marking';
$string['submission'] = 'Submission';
$string['submissiondraft'] = 'Submission draft';
$string['submissionfeedback'] = 'Submission feedback';
$string['submissions'] = 'Submissions';
$string['submissionsaved'] = 'Your changes have been saved';
$string['submissionsnotgraded'] = '$a submissions not graded';
$string['submitassignment'] = 'Submit your assignment using this form';
$string['submitedformarking'] = 'Assignment was already submitted for marking and can not be updated';
$string['submitformarking'] = 'Final submission for assignment marking';
$string['submitted'] = 'Submitted';
$string['submittedfiles'] = 'Submitted files';
$string['typeoffline'] = 'Offline activity';
$string['typeonline'] = 'Online text';
$string['typeupload'] = 'Advanced uploading of files';
$string['typeuploadsingle'] = 'Upload a single file';
$string['unfinalize'] = 'Revert to draft';
$string['uploadbadname'] = 'This filename contained strange characters and couldn\'t be uploaded';
$string['uploadedfiles'] = 'uploaded files';
$string['uploaderror'] = 'An error happened while saving the file on the server';
$string['uploadfailnoupdate'] = 'File was uploaded OK but could not update your submission!';
$string['uploadfiletoobig'] = 'Sorry, but that file is too big (limit is $a bytes)';
$string['uploadnofilefound'] = 'No file was found - are you sure you selected one to upload?';
$string['uploadnotregistered'] = '\'$a\' was uploaded OK but submission did not register!';
$string['uploadsuccess'] = 'Uploaded \'$a\' successfully';
$string['viewfeedback'] = 'View assignment grades and feedback';
$string['viewsubmissions'] = 'View $a submitted assignments';
$string['yoursubmission'] = 'Your submission';

?>
